==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkPolyDataConnectivityFilter.java <==
// java wrapper for vtkPolyDataConnectivityFilter object
//

package vtk;
import vtk.*;

public class vtkPolyDataConnectivityFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetRegionSizes_2();
  public vtkIdTypeArray GetRegionSizes() {
    long temp = GetRegionSizes_2();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarConnectivity_3(int id0);
  public void SetScalarConnectivity(int id0)
    { SetScalarConnectivity_3(id0); }

  private native int GetScalarConnectivity_4();
  public int GetScalarConnectivity()
    { return GetScalarConnectivity_4(); }

  private native void ScalarConnectivityOn_5();
  public void ScalarConnectivityOn()
    { ScalarConnectivityOn_5(); }

  private native void ScalarConnectivityOff_6();
  public void ScalarConnectivityOff()
    { ScalarConnectivityOff_6(); }

  private native void SetFullScalarConnectivity_7(int id0);
  public void SetFullScalarConnectivity(int id0)
    { SetFullScalarConnectivity_7(id0); }

  private native int GetFullScalarConnectivity_8();
  public int GetFullScalarConnectivity()
    { return GetFullScalarConnectivity_8(); }

  private native void FullScalarConnectivityOn_9();
  public void FullScalarConnectivityOn()
    { FullScalarConnectivityOn_9(); }

  private native void FullScalarConnectivityOff_10();
  public void FullScalarConnectivityOff()
    { FullScalarConnectivityOff_10(); }

  private native void SetScalarRange_11(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_11(id0,id1); }

  private native void SetScalarRange_12(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_12(id0); }

  private native double[] GetScalarRange_13();
  public double[] GetScalarRange()
    { return GetScalarRange_13(); }

  private native void SetExtractionMode_14(int id0);
  public void SetExtractionMode(int id0)
    { SetExtractionMode_14(id0); }

  private native int GetExtractionModeMinValue_15();
  public int GetExtractionModeMinValue()
    { return GetExtractionModeMinValue_15(); }

  private native int GetExtractionModeMaxValue_16();
  public int GetExtractionModeMaxValue()
    { return GetExtractionModeMaxValue_16(); }

  private native int GetExtractionMode_17();
  public int GetExtractionMode()
    { return GetExtractionMode_17(); }

  private native void SetExtractionModeToPointSeededRegions_18();
  public void SetExtractionModeToPointSeededRegions()
    { SetExtractionModeToPointSeededRegions_18(); }

  private native void SetExtractionModeToCellSeededRegions_19();
  public void SetExtractionModeToCellSeededRegions()
    { SetExtractionModeToCellSeededRegions_19(); }

  private native void SetExtractionModeToLargestRegion_20();
  public void SetExtractionModeToLargestRegion()
    { SetExtractionModeToLargestRegion_20(); }

  private native void SetExtractionModeToSpecifiedRegions_21();
  public void SetExtractionModeToSpecifiedRegions()
    { SetExtractionModeToSpecifiedRegions_21(); }

  private native void SetExtractionModeToClosestPointRegion_22();
  public void SetExtractionModeToClosestPointRegion()
    { SetExtractionModeToClosestPointRegion_22(); }

  private native void SetExtractionModeToAllRegions_23();
  public void SetExtractionModeToAllRegions()
    { SetExtractionModeToAllRegions_23(); }

  private native String GetExtractionModeAsString_24();
  public String GetExtractionModeAsString()
    { return GetExtractionModeAsString_24(); }

  private native void InitializeSeedList_25();
  public void InitializeSeedList()
    { InitializeSeedList_25(); }

  private native void AddSeed_26(int id0);
  public void AddSeed(int id0)
    { AddSeed_26(id0); }

  private native void DeleteSeed_27(int id0);
  public void DeleteSeed(int id0)
    { DeleteSeed_27(id0); }

  private native void InitializeSpecifiedRegionList_28();
  public void InitializeSpecifiedRegionList()
    { InitializeSpecifiedRegionList_28(); }

  private native void AddSpecifiedRegion_29(int id0);
  public void AddSpecifiedRegion(int id0)
    { AddSpecifiedRegion_29(id0); }

  private native void DeleteSpecifiedRegion_30(int id0);
  public void DeleteSpecifiedRegion(int id0)
    { DeleteSpecifiedRegion_30(id0); }

  private native void SetClosestPoint_31(double id0,double id1,double id2);
  public void SetClosestPoint(double id0,double id1,double id2)
    { SetClosestPoint_31(id0,id1,id2); }

  private native void SetClosestPoint_32(double id0[]);
  public void SetClosestPoint(double id0[])
    { SetClosestPoint_32(id0); }

  private native double[] GetClosestPoint_33();
  public double[] GetClosestPoint()
    { return GetClosestPoint_33(); }

  private native int GetNumberOfExtractedRegions_34();
  public int GetNumberOfExtractedRegions()
    { return GetNumberOfExtractedRegions_34(); }

  private native void SetColorRegions_35(int id0);
  public void SetColorRegions(int id0)
    { SetColorRegions_35(id0); }

  private native int GetColorRegions_36();
  public int GetColorRegions()
    { return GetColorRegions_36(); }

  private native void ColorRegionsOn_37();
  public void ColorRegionsOn()
    { ColorRegionsOn_37(); }

  private native void ColorRegionsOff_38();
  public void ColorRegionsOff()
    { ColorRegionsOff_38(); }

  private native void SetMarkVisitedPointIds_39(int id0);
  public void SetMarkVisitedPointIds(int id0)
    { SetMarkVisitedPointIds_39(id0); }

  private native int GetMarkVisitedPointIds_40();
  public int GetMarkVisitedPointIds()
    { return GetMarkVisitedPointIds_40(); }

  private native void MarkVisitedPointIdsOn_41();
  public void MarkVisitedPointIdsOn()
    { MarkVisitedPointIdsOn_41(); }

  private native void MarkVisitedPointIdsOff_42();
  public void MarkVisitedPointIdsOff()
    { MarkVisitedPointIdsOff_42(); }

  private native long GetVisitedPointIds_43();
  public vtkIdList GetVisitedPointIds() {
    long temp = GetVisitedPointIds_43();

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputPointsPrecision_44(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_44(id0); }

  private native int GetOutputPointsPrecision_45();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_45(); }

  public vtkPolyDataConnectivityFilter() { super(); }

  public vtkPolyDataConnectivityFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-2-armv7h.pkg.tar.xz: vtk/vtkPolyDataConnectivityFilter.java <==
// java wrapper for vtkPolyDataConnectivityFilter object
//

package vtk;
import vtk.*;

public class vtkPolyDataConnectivityFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetRegionSizes_2();
  public vtkIdTypeArray GetRegionSizes() {
    long temp = GetRegionSizes_2();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScalarConnectivity_3(int id0);
  public void SetScalarConnectivity(int id0)
    { SetScalarConnectivity_3(id0); }

  private native int GetScalarConnectivity_4();
  public int GetScalarConnectivity()
    { return GetScalarConnectivity_4(); }

  private native void ScalarConnectivityOn_5();
  public void ScalarConnectivityOn()
    { ScalarConnectivityOn_5(); }

  private native void ScalarConnectivityOff_6();
  public void ScalarConnectivityOff()
    { ScalarConnectivityOff_6(); }

  private native void SetFullScalarConnectivity_7(int id0);
  public void SetFullScalarConnectivity(int id0)
    { SetFullScalarConnectivity_7(id0); }

  private native int GetFullScalarConnectivity_8();
  public int GetFullScalarConnectivity()
    { return GetFullScalarConnectivity_8(); }

  private native void FullScalarConnectivityOn_9();
  public void FullScalarConnectivityOn()
    { FullScalarConnectivityOn_9(); }

  private native void FullScalarConnectivityOff_10();
  public void FullScalarConnectivityOff()
    { FullScalarConnectivityOff_10(); }

  private native void SetScalarRange_11(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_11(id0,id1); }

  private native void SetScalarRange_12(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_12(id0); }

  private native double[] GetScalarRange_13();
  public double[] GetScalarRange()
    { return GetScalarRange_13(); }

  private native void SetExtractionMode_14(int id0);
  public void SetExtractionMode(int id0)
    { SetExtractionMode_14(id0); }

  private native int GetExtractionModeMinValue_15();
  public int GetExtractionModeMinValue()
    { return GetExtractionModeMinValue_15(); }

  private native int GetExtractionModeMaxValue_16();
  public int GetExtractionModeMaxValue()
    { return GetExtractionModeMaxValue_16(); }

  private native int GetExtractionMode_17();
  public int GetExtractionMode()
    { return GetExtractionMode_17(); }

  private native void SetExtractionModeToPointSeededRegions_18();
  public void SetExtractionModeToPointSeededRegions()
    { SetExtractionModeToPointSeededRegions_18(); }

  private native void SetExtractionModeToCellSeededRegions_19();
  public void SetExtractionModeToCellSeededRegions()
    { SetExtractionModeToCellSeededRegions_19(); }

  private native void SetExtractionModeToLargestRegion_20();
  public void SetExtractionModeToLargestRegion()
    { SetExtractionModeToLargestRegion_20(); }

  private native void SetExtractionModeToSpecifiedRegions_21();
  public void SetExtractionModeToSpecifiedRegions()
    { SetExtractionModeToSpecifiedRegions_21(); }

  private native void SetExtractionModeToClosestPointRegion_22();
  public void SetExtractionModeToClosestPointRegion()
    { SetExtractionModeToClosestPointRegion_22(); }

  private native void SetExtractionModeToAllRegions_23();
  public void SetExtractionModeToAllRegions()
    { SetExtractionModeToAllRegions_23(); }

  private native String GetExtractionModeAsString_24();
  public String GetExtractionModeAsString()
    { return GetExtractionModeAsString_24(); }

  private native void InitializeSeedList_25();
  public void InitializeSeedList()
    { InitializeSeedList_25(); }

  private native void AddSeed_26(int id0);
  public void AddSeed(int id0)
    { AddSeed_26(id0); }

  private native void DeleteSeed_27(int id0);
  public void DeleteSeed(int id0)
    { DeleteSeed_27(id0); }

  private native void InitializeSpecifiedRegionList_28();
  public void InitializeSpecifiedRegionList()
    { InitializeSpecifiedRegionList_28(); }

  private native void AddSpecifiedRegion_29(int id0);
  public void AddSpecifiedRegion(int id0)
    { AddSpecifiedRegion_29(id0); }

  private native void DeleteSpecifiedRegion_30(int id0);
  public void DeleteSpecifiedRegion(int id0)
    { DeleteSpecifiedRegion_30(id0); }

  private native void SetClosestPoint_31(double id0,double id1,double id2);
  public void SetClosestPoint(double id0,double id1,double id2)
    { SetClosestPoint_31(id0,id1,id2); }

  private native void SetClosestPoint_32(double id0[]);
  public void SetClosestPoint(double id0[])
    { SetClosestPoint_32(id0); }

  private native double[] GetClosestPoint_33();
  public double[] GetClosestPoint()
    { return GetClosestPoint_33(); }

  private native int GetNumberOfExtractedRegions_34();
  public int GetNumberOfExtractedRegions()
    { return GetNumberOfExtractedRegions_34(); }

  private native void SetColorRegions_35(int id0);
  public void SetColorRegions(int id0)
    { SetColorRegions_35(id0); }

  private native int GetColorRegions_36();
  public int GetColorRegions()
    { return GetColorRegions_36(); }

  private native void ColorRegionsOn_37();
  public void ColorRegionsOn()
    { ColorRegionsOn_37(); }

  private native void ColorRegionsOff_38();
  public void ColorRegionsOff()
    { ColorRegionsOff_38(); }

  private native void SetMarkVisitedPointIds_39(int id0);
  public void SetMarkVisitedPointIds(int id0)
    { SetMarkVisitedPointIds_39(id0); }

  private native int GetMarkVisitedPointIds_40();
  public int GetMarkVisitedPointIds()
    { return GetMarkVisitedPointIds_40(); }

  private native void MarkVisitedPointIdsOn_41();
  public void MarkVisitedPointIdsOn()
    { MarkVisitedPointIdsOn_41(); }

  private native void MarkVisitedPointIdsOff_42();
  public void MarkVisitedPointIdsOff()
    { MarkVisitedPointIdsOff_42(); }

  private native long GetVisitedPointIds_43();
  public vtkIdList GetVisitedPointIds() {
    long temp = GetVisitedPointIds_43();

    if (temp == 0) return null;
    return (vtkIdList)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOutputPointsPrecision_44(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_44(id0); }

  private native int GetOutputPointsPrecision_45();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_45(); }

  public vtkPolyDataConnectivityFilter() { super(); }

  public vtkPolyDataConnectivityFilter(long id) { super(id); }
  public native long   VTKInit();

}
